.. _installation:

============
Installation
============

Install shellplot via ``pip``::

    pip install --upgrade shellplot


This will install the latest stable version, as well as the required
dependencies.


Dependencies
-------------

Shellplot has the following dependencies, all of which are installed automatically
with the above installation command:

- python 3.6 or newer
- `Numpy`_
- `Pandas`_

.. _NumPy: http://www.numpy.org/
.. _Pandas: http://pandas.pydata.org
